netapp_ontap.models.totp_post API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.totp_post`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class TotpPostSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the TotpPost object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `account: Account GET POST PATCH`

    The account field of the totp_post.

  `comment: str GET POST PATCH`

    Optional comment for the TOTP profile.

  `emergency_codes: List[str] GET`

    TOTP profile emergency codes for a user. These codes are for emergency use when a user cannot access 2FA codes through other means.

    Example: "17503785"

  `enabled: bool GET PATCH`

    Status of the TOTP profile.

    Example: true

  `install_url: str GET`

    TOTP profile installation URL for a user.

  `links: SelfLink GET`

    The links field of the totp_post.

  `owner: Svm GET POST`

    The owner field of the totp_post.

  `scope: str GET`

    Scope of the entity. Set to "cluster" for cluster owned objects and to "svm" for SVM owned objects.

    Valid choices:

    - cluster
    - svm
  `secret_key: str GET`

    TOTP profile secret key for a user.

  `sha_fingerprint: str GET`

    SHA fingerprint for the TOTP secret key.

  `verification_code: str GET`

    TOTP profile verification code for a user.